Struct WpCursorShapeManagerV1
pub struct WpCursorShapeManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
cursor shape manager
This global offers an alternative, optional way to set cursor images. This new way uses enumerated cursors instead of a wl_surface like wl_pointer.set_cursor does.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Request enum for this interface.